@@ -82,6 +82,12 @@ make_choose_all_table <- function(df, variable) {
     
   }
   
+  # fix no visible bindings for global variables in CRAN check
+  blah <- NULL
+  value <- NULL
+  What <- NULL
+  Count <- NULL
+  
   counts <- the_vars_df |> 
     dplyr::mutate(dplyr::across(tidyselect::everything(), ~ . %in% c("1", "Checked"))) %>%
     dplyr::mutate(dplyr::across(
@@ -92,7 +98,7 @@ make_choose_all_table <- function(df, variable) {
     )) %>%
     dplyr::summarise(across(everything(), ~ sum(.x, na.rm = TRUE))) %>%
     dplyr::mutate(blah = "x") %>%
-    tidyr::pivot_longer(-.data$blah, names_to = "thingy", values_to = "Count")
+    tidyr::pivot_longer(-`blah`, names_to = "thingy", values_to = "Count")
   
   aTable <-
     counts %>%
@@ -101,8 +107,8 @@ make_choose_all_table <- function(df, variable) {
       getLabel2(df, .x)
     }) %>%
     tibble::enframe(name = NULL) %>% # new variable is value
-    dplyr::rename("What" = .data$value) %>%
+    dplyr::rename("What" = `value`) %>%
     dplyr::bind_cols(counts) %>%
-    dplyr::select(.data$What, .data$Count)
+    dplyr::select(`What`, `Count`)
   aTable
 }
